@@ -103,6 +103,8 @@ class PlatoTask(BaseModel):
     eval_config: Optional[BasePlatoEvalConfig] = None
     average_time: Optional[float] = None
     average_steps: Optional[int] = None
+    num_validator_human_scores: Optional[int] = None
+    default_scoring_config: Optional[Dict[str, Any]] = None
 
     @field_serializer('eval_config')
     def serialize_eval_config(self, eval_config: Optional[BasePlatoEvalConfig], _info):
